@@ -292,7 +292,7 @@ void lookupUnknownSymbols(const char *appname)
 
 int match(const char *s1, const char *s2)
 {
-  register int result;
+  int result;
   while(true)
   {
     result = *s1 - *s2;
